/* OGMDvd - A library for reading dvd video
 * Copyright (C) 2004 Olivier Rolland <billl@esil.univ-mrs.fr>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef __OGMDVD_H__
#define __OGMDVD_H__

#include <glib.h>

G_BEGIN_DECLS

typedef enum
{
  OGMDVD_AUDIO_FORMAT_AC3      = 0,
  OGMDVD_AUDIO_FORMAT_MPEG1    = 2,
  OGMDVD_AUDIO_FORMAT_MPEG2EXT = 3,
  OGMDVD_AUDIO_FORMAT_LPCM     = 4,
  OGMDVD_AUDIO_FORMAT_SDDS     = 5,
  OGMDVD_AUDIO_FORMAT_DTS      = 6
} OGMDvdAudioFormat;

typedef enum
{
  OGMDVD_AUDIO_CHANNELS_MONO      = 0,
  OGMDVD_AUDIO_CHANNELS_STEREO    = 1,
  OGMDVD_AUDIO_CHANNELS_SURROUND  = 3,
  OGMDVD_AUDIO_CHANNELS_5_1       = 5
} OGMDvdAudioChannels;

typedef enum
{
  OGMDVD_VIDEO_FORMAT_NTSC = 0,
  OGMDVD_VIDEO_FORMAT_PAL  = 1
} OGMDvdVideoFormat;

typedef enum
{
  OGMDVD_VIDEO_ASPECT_4_3  = 0,
  OGMDVD_VIDEO_ASPECT_16_9 = 1,
} OGMDvdVideoAspect;

typedef enum
{
  OGMDVD_VIDEO_QUANT_16  = 0,
  OGMDVD_VIDEO_QUANT_20  = 1,
  OGMDVD_VIDEO_QUANT_24  = 2,
  OGMDVD_VIDEO_QUANT_DRC = 3
} OGMDvdVideoQuant;

typedef enum
{
  OGMDVD_VIDEO_DISPLAY_PS_LETTER = 0,
  OGMDVD_VIDEO_DISPLAY_PAN_SCAN  = 1,
  OGMDVD_VIEO_DISPLAY_LETTERBOX  = 2,
} OGMDvdVideoDisplay;

enum
{
  OGMDVD_LANGUAGE_ISO639_1,
  OGMDVD_LANGUAGE_ISO639_2,
  OGMDVD_LANGUAGE_NAME
};

typedef struct
{
  guint hour;
  guint min;
  guint sec;
  guint frames;
} OGMDvdTime;

typedef struct _OGMDvd OGMDvd;
typedef struct _OGMDvdVideoStream OGMDvdVideoStream;
typedef struct _OGMDvdAudioStream OGMDvdAudioStream;
typedef struct _OGMDvdSubpStream  OGMDvdSubpStream;

/*
 * DVD
 */

OGMDvd *  ogmdvd_open       (const gchar *dev);
void      ogmdvd_ref        (OGMDvd      *dvd);
void      ogmdvd_unref      (OGMDvd      *dvd);
gchar *   ogmdvd_get_title  (OGMDvd      *dvd);
G_CONST_RETURN
gchar *   ogmdvd_get_device (OGMDvd      *dvd);

/*
 * Video Streams
 */

gint                 ogmdvd_get_num_video_streams (OGMDvd  *dvd);
OGMDvdVideoStream *  ogmdvd_get_video_stream      (OGMDvd  *dvd,
                                                   guint vid);

void     ogmdvd_video_stream_ref                   (OGMDvdVideoStream *video);
void     ogmdvd_video_stream_unref                 (OGMDvdVideoStream *video);
OGMDvd * ogmdvd_video_stream_get_dvd               (OGMDvdVideoStream *video);
gint     ogmdvd_video_stream_get_id                (OGMDvdVideoStream *video);
void     ogmdvd_video_stream_get_raw_size          (OGMDvdVideoStream *video,
                                                    guint             *width,
                                                    guint             *height);
glong    ogmdvd_video_stream_get_length            (OGMDvdVideoStream *video,
                                                    OGMDvdTime        *time_);
gfloat   ogmdvd_video_stream_get_rate              (OGMDvdVideoStream *video);
gfloat   ogmdvd_video_stream_get_aspect_ratio      (OGMDvdVideoStream *video);
gint     ogmdvd_video_stream_get_display_aspect    (OGMDvdVideoStream *video);
gint     ogmdvd_video_stream_get_format            (OGMDvdVideoStream *video);
gint     ogmdvd_video_stream_get_display_format    (OGMDvdVideoStream *video);
gint     ogmdvd_video_stream_get_num_audio_streams (OGMDvdVideoStream *video);
gint     ogmdvd_video_stream_get_num_subp_streams  (OGMDvdVideoStream *video);

/*
 * Audio Streams
 */

void     ogmdvd_audio_stream_ref                   (OGMDvdAudioStream *audio);
void     ogmdvd_audio_stream_unref                 (OGMDvdAudioStream *audio);
gint     ogmdvd_audio_stream_get_id                (OGMDvdAudioStream *audio);
gint     ogmdvd_audio_stream_get_type              (OGMDvdAudioStream *audio);
gint     ogmdvd_audio_stream_get_format            (OGMDvdAudioStream *audio);
gint     ogmdvd_audio_stream_get_channels          (OGMDvdAudioStream *audio);
gint     ogmdvd_audio_stream_get_language          (OGMDvdAudioStream *audio);
gint     ogmdvd_audio_stream_get_quantization      (OGMDvdAudioStream *audio);

/*
 * Chapters
 */

gint     ogmdvd_video_stream_get_num_chapters      (OGMDvdVideoStream *video);
glong    ogmdvd_video_stream_get_chapters_length   (OGMDvdVideoStream *video, 
                                                    OGMDvdTime        *time_, 
                                                    guint             start,
                                                    gint              end);

/*
 * Subp Streams
 */

void     ogmdvd_subp_stream_ref                    (OGMDvdSubpStream  *subp);
void     ogmdvd_subp_stream_unref                  (OGMDvdSubpStream  *subp);
gint     ogmdvd_subp_stream_get_id                 (OGMDvdSubpStream  *subp);
gint     ogmdvd_subp_stream_get_type               (OGMDvdSubpStream  *subp);
gint     ogmdvd_subp_stream_get_language           (OGMDvdSubpStream  *subp);

/*
 * Convenience
 */

OGMDvdVideoStream * ogmdvd_audio_stream_get_video_stream (OGMDvdAudioStream *audio);
OGMDvdAudioStream * ogmdvd_video_stream_get_audio_stream (OGMDvdVideoStream *video,
                                                          guint             aid);
OGMDvdVideoStream * ogmdvd_subp_stream_get_video_stream  (OGMDvdSubpStream  *subp);
OGMDvdSubpStream *  ogmdvd_video_stream_get_subp_stream  (OGMDvdVideoStream *video,
                                                          guint             sid);

/*
 * Misc
 */
G_CONST_RETURN 
gchar *  ogmdvd_get_language_name       (gint code);
G_CONST_RETURN 
gchar *  ogmdvd_get_language_iso639_1   (gint code);
G_CONST_RETURN 
gchar *  ogmdvd_get_language_iso639_2   (gint code);
G_CONST_RETURN
gchar *  ogmdvd_get_video_format_name   (gint format);
G_CONST_RETURN
gchar *  ogmdvd_get_video_aspect_name   (gint aspect);
G_CONST_RETURN
gchar *  ogmdvd_get_audio_type_name     (gint type);
G_CONST_RETURN
gchar *  ogmdvd_get_audio_format_name   (gint format);
G_CONST_RETURN
gchar *  ogmdvd_get_audio_channels_name (gint channels);
G_CONST_RETURN 
gchar *  ogmdvd_get_subp_type_name      (gint type);

G_END_DECLS

#endif /* __OGMDVD_H__ */

