/* OGMSpawn - A library to spawn processes
 * Copyright (C) 2004 Olivier Rolland <billl@esil.univ-mrs.fr>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef __OGMSP_CONTAINER_H__
#define __OGMSP_CONTAINER_H__

#include <ogmsp-spawn.h>

G_BEGIN_DECLS

#define OGMSP_TYPE_CONTAINER           (ogmsp_container_get_type ())
#define OGMSP_CONTAINER(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMSP_TYPE_CONTAINER, OGMSpContainer))
#define OGMSP_CONTAINER_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), OGMSP_TYPE_CONTAINER, OGMSpContainerClass))
#define OGMSP_IS_CONTAINER(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMSP_TYPE_CONTAINER))
#define OGMSP_IS_CONTAINER_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMSP_TYPE_CONTAINER))
#define OGMSP_CONTAINER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OGMSP_TYPE_CONTAINER, OGMSpContainerClass))

typedef void (* OGMSpCallback) (OGMSpSpawn *spawn,
                                gpointer   data);

typedef struct _OGMSpContainer      OGMSpContainer;
typedef struct _OGMSpContainerPriv  OGMSpContainerPriv;
typedef struct _OGMSpContainerClass OGMSpContainerClass;

struct _OGMSpContainer
{
  OGMSpSpawn parent_instance;

  OGMSpContainerPriv *priv;
};

struct _OGMSpContainerClass
{
  OGMSpSpawnClass parent_class;

  /* signals */
  void (* add)    (OGMSpContainer *container,
                   OGMSpSpawn     *child);
  void (* remove) (OGMSpContainer *container,
                   OGMSpSpawn     *spawn);
  /* vtable */
  void (* forall) (OGMSpContainer *container,
                   OGMSpCallback  callback,
                   gpointer       data);
};

GType   ogmsp_container_get_type (void);

void    ogmsp_container_add      (OGMSpContainer *container,
                                  OGMSpSpawn     *spawn);
void    ogmsp_container_remove   (OGMSpContainer *container,
                                  OGMSpSpawn     *spawn);
void    ogmsp_container_foreach  (OGMSpContainer *container,
                                  OGMSpCallback  callback,
                                  gpointer       data);

G_END_DECLS

#endif /* __OGMSP_CONTAINER_H__ */

