/* OGMSpawn - A library to exec processes
 * Copyright (C) 2004 Olivier Rolland <billl@esil.univ-mrs.fr>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef __OGMSP_EXEC_H__
#define __OGMSP_EXEC_H__

#include <ogmsp-spawn.h>

G_BEGIN_DECLS

#define OGMSP_TYPE_EXEC          (ogmsp_exec_get_type ())
#define OGMSP_EXEC(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMSP_TYPE_EXEC, OGMSpExec))
#define OGMSP_EXEC_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMSP_TYPE_EXEC, OGMSpExecClass))
#define OGMSP_IS_EXEC(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMSP_TYPE_EXEC))
#define OGMSP_IS_EXEC_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMSP_TYPE_EXEC))

typedef struct _OGMSpExec      OGMSpExec;
typedef struct _OGMSpExecPriv  OGMSpExecPriv;
typedef struct _OGMSpExecClass OGMSpExecClass;

typedef gdouble (* OGMSpWatch) (OGMSpExec   *exec,
                                const gchar *buffer,
                                gpointer    data);

struct _OGMSpExec
{
  OGMSpSpawn parent_instance;

  OGMSpExecPriv *priv;
};

struct _OGMSpExecClass
{
  OGMSpSpawnClass parent_class;
};

GType         ogmsp_exec_get_type          (void);

OGMSpSpawn *  ogmsp_exec_new               (const gchar *command_line);
OGMSpSpawn *  ogmsp_exec_newv              (gchar       **argv);

void          ogmsp_exec_construct         (OGMSpExec   *exec,
                                            const gchar *command_line);
void          ogmsp_exec_constructv        (OGMSpExec   *exec,
                                            gchar       **argv);

void          ogmsp_exec_add_watch         (OGMSpExec   *exec,
                                            OGMSpWatch  watch_func,
                                            gpointer    watch_data);
void          ogmsp_exec_add_watch_full    (OGMSpExec   *exec,
                                            OGMSpWatch  watch_func,
                                            gpointer    watch_data,
                                            gboolean    watch_out,
                                            gboolean    watch_err,
                                            gboolean    swapped);

G_END_DECLS

#endif /* __OGMSP_EXEC_H__ */

