/* OGMSpawn - A library to spawn processes
 * Copyright (C) 2004 Olivier Rolland <billl@esil.univ-mrs.fr>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef __OGMSP_SPAWN_H__
#define __OGMSP_SPAWN_H__

#include <glib-object.h>

G_BEGIN_DECLS

#define OGMSP_TYPE_SPAWN          (ogmsp_spawn_get_type ())
#define OGMSP_SPAWN(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMSP_TYPE_SPAWN, OGMSpSpawn))
#define OGMSP_SPAWN_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMSP_TYPE_SPAWN, OGMSpSpawnClass))
#define OGMSP_IS_SPAWN(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMSP_TYPE_SPAWN))
#define OGMSP_IS_SPAWN_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMSP_TYPE_SPAWN))
#define OGMSP_SPAWN_ERROR         (ogmsp_spawn_error_quark ())

typedef enum
{
  OGMSP_ERROR_NONE,
  OGMSP_ERROR_CANCEL
} OGMSpError;

typedef struct _OGMSpSpawn      OGMSpSpawn;
typedef struct _OGMSpSpawnPriv  OGMSpSpawnPriv;
typedef struct _OGMSpSpawnClass OGMSpSpawnClass;

struct _OGMSpSpawn
{
  GObject parent_instance;

  OGMSpSpawnPriv *priv;
};

struct _OGMSpSpawnClass
{
  GObjectClass parent_class;

  gint (* run)      (OGMSpSpawn *spawn);
  void (* cancel)   (OGMSpSpawn *spawn);
  void (* progress) (OGMSpSpawn *spawn,
                     gdouble    fraction);
};

GType        ogmsp_spawn_get_type    (void);
GQuark       ogmsp_spawn_error_quark (void);

gint         ogmsp_spawn_run         (OGMSpSpawn *spawn);
void         ogmsp_spawn_cancel      (OGMSpSpawn *spawn);

void         ogmsp_spawn_set_async   (OGMSpSpawn *spawn,
                                      gboolean   async);
gboolean     ogmsp_spawn_get_async   (OGMSpSpawn *spawn);

OGMSpSpawn * ogmsp_spawn_get_parent  (OGMSpSpawn *spawn);
void         ogmsp_spawn_set_parent  (OGMSpSpawn *spawn,
                                      OGMSpSpawn *parent);

G_END_DECLS

#endif /* __OGMSP_SPAWN_H__ */

